[zaptel-commits] mattf: branch 1.2 r4028 - /branches/1.2/wcte12xp/

SVN commits to the Zaptel project zaptel-commits at lists.digium.com
Wed Mar 19 14:58:37 CDT 2008


Author: mattf
Date: Wed Mar 19 14:58:37 2008
New Revision: 4028

URL: http://svn.digium.com/view/zaptel?view=rev&rev=4028
Log:
Add support for new VPMADT032 fw for the TE120

Modified:
    branches/1.2/wcte12xp/GpakApi.c
    branches/1.2/wcte12xp/GpakApi.h
    branches/1.2/wcte12xp/GpakErrs.h
    branches/1.2/wcte12xp/GpakHpi.h
    branches/1.2/wcte12xp/VPMADT032.bin
    branches/1.2/wcte12xp/gpakenum.h

Modified: branches/1.2/wcte12xp/GpakApi.c
URL: http://svn.digium.com/view/zaptel/branches/1.2/wcte12xp/GpakApi.c?view=diff&rev=4028&r1=4027&r2=4028
==============================================================================
--- branches/1.2/wcte12xp/GpakApi.c (original)
+++ branches/1.2/wcte12xp/GpakApi.c Wed Mar 19 14:58:37 2008
@@ -128,10 +128,10 @@
     DSP_ADDRESS IfBlockPntr; /* Interface Block pointer */
     DSP_WORD DspStatus;      /* DSP Status */
     DSP_WORD DspChannels;    /* number of DSP channels */
-    //DSP_WORD DspConfs;       /* number of DSP conferences */
-    //DSP_ADDRESS PktBufrMem;  /* address of Packet Buffer */
+    DSP_WORD DspConfs;       /* number of DSP conferences */
+    DSP_ADDRESS PktBufrMem;  /* address of Packet Buffer */
     DSP_WORD  Temp[2];
-    //unsigned short int i;    /* loop index / counter */
+    unsigned short int i;    /* loop index / counter */
 
     /* Read the pointer to the Interface Block. */
     gpakReadDspMemory(DspId, DSP_IFBLK_ADDRESS, 2, Temp);
@@ -560,7 +560,7 @@
                     ((pPortConfig->RxFrameSyncPolarity2 << 4) & 0x0010) |
                     ((pPortConfig->TxFrameSyncPolarity2 << 3) & 0x0008) |
                     ((pPortConfig->CompandingMode2 << 1) & 0x0006) |
-                    (pPortConfig->SerialWordSize1 & 0x0001));
+                    (pPortConfig->SerialWordSize2 & 0x0001));
 
     MsgBuffer[12] = (DSP_WORD)
                    (((pPortConfig->DxDelay3 << 11) & 0x0800) |
@@ -672,7 +672,7 @@
                        ((pChanConfig->SoftwareCompand & 3) << 2) |
                         (pChanConfig->EcanEnableB << 1) | 
                         (pChanConfig->EcanEnableA & 1)
-						);
+                        );
                         
         MsgBuffer[7]   = (DSP_WORD)
                          pChanConfig->EcanParametersA.EcanTapLength;       
@@ -732,8 +732,16 @@
                          pChanConfig->EcanParametersB.EcanNumFirSegments;  
         MsgBuffer[34]  = (DSP_WORD)
                          pChanConfig->EcanParametersB.EcanFirSegmentLen;   
-
-        MsgLength = 70; // byte number == 35*2 
+        MsgBuffer[35]  = (DSP_WORD)
+                         pChanConfig->EcanParametersA.EcanTandemOperationEnable;  
+        MsgBuffer[36]  = (DSP_WORD)
+                         pChanConfig->EcanParametersA.EcanMixedFourWireMode;   
+        MsgBuffer[37]  = (DSP_WORD)
+                         pChanConfig->EcanParametersB.EcanTandemOperationEnable;  
+        MsgBuffer[38]  = (DSP_WORD)
+                         pChanConfig->EcanParametersB.EcanMixedFourWireMode;   
+
+        MsgLength = 78; // byte number == 39*2 
         break;
 
 
@@ -889,7 +897,7 @@
     DSP_WORD TakeIndex;     /* event fifo take index */
     DSP_WORD WordsReady;    /* number words ready for read out of event fifo */
     DSP_WORD EventError;    /* flag indicating error with event fifo msg  */
-    //DSP_WORD *pDebugData;   /* debug data buffer pointer in event data struct */
+    DSP_WORD *pDebugData;   /* debug data buffer pointer in event data struct */
 
     /* Make sure the DSP Id is valid. */
     if (DspId >= MAX_DSP_CORES)

Modified: branches/1.2/wcte12xp/GpakApi.h
URL: http://svn.digium.com/view/zaptel/branches/1.2/wcte12xp/GpakApi.h?view=diff&rev=4028&r1=4027&r2=4028
==============================================================================
--- branches/1.2/wcte12xp/GpakApi.h (original)
+++ branches/1.2/wcte12xp/GpakApi.h Wed Mar 19 14:58:37 2008
@@ -77,6 +77,9 @@
     short int EcanCrossCorrLimit;  // Echo Can Cross Correlation limit 
     short int EcanNumFirSegments;  // Echo Can Num FIR Segments 
     short int EcanFirSegmentLen;   // Echo Can FIR Segment Length 
+    short int EcanTandemOperationEnable;   //Enable tandem operation 
+    short int EcanMixedFourWireMode; 	// Handle possible 4-wire (echo-free) lines
+
 } GpakEcanParms_t;
 
 /* Definition of a Channel Configuration information structure. */

Modified: branches/1.2/wcte12xp/GpakErrs.h
URL: http://svn.digium.com/view/zaptel/branches/1.2/wcte12xp/GpakErrs.h?view=diff&rev=4028&r1=4027&r2=4028
==============================================================================
--- branches/1.2/wcte12xp/GpakHpi.h (original)
+++ branches/1.2/wcte12xp/GpakHpi.h Wed Mar 19 14:58:37 2008
@@ -75,6 +75,6 @@
 #define MSG_READ_DSP_MEMORY         49 /* read small section of DSP's memory */
 #define MSG_READ_DSP_MEMORY_REPLY   50 /* read memory reply */
 
-#define MSG_ACCESSGPIO				51
-#define MSG_ACCESSGPIO_REPLY		52
+#define MSG_ACCESSGPIO              51
+#define MSG_ACCESSGPIO_REPLY        52
 #endif  /* prevent multiple inclusion */

Modified: branches/1.2/wcte12xp/VPMADT032.bin
URL: http://svn.digium.com/view/zaptel/branches/1.2/wcte12xp/VPMADT032.bin?view=diff&rev=4028&r1=4027&r2=4028
==============================================================================
Binary files - no diff available.

Modified: branches/1.2/wcte12xp/gpakenum.h
URL: http://svn.digium.com/view/zaptel/branches/1.2/wcte12xp/gpakenum.h?view=diff&rev=4028&r1=4027&r2=4028
==============================================================================
--- branches/1.2/wcte12xp/gpakenum.h (original)
+++ branches/1.2/wcte12xp/gpakenum.h Wed Mar 19 14:58:37 2008
@@ -114,7 +114,7 @@
 
     EnableMuLawSwCompanding  = 6,// Enable Mu-law Software companding
     EnableALawSwCompanding  = 7, // Enable Mu-law Software companding
-    BypassSwCompanding  = 8,     // Bypass Software companding
+    BypassSwCompanding   = 8,    // Bypass Software companding
 	EnableDTMFMuteA       = 9,   // Mute A side Dtmf digit after tone detected
 	DisableDTMFMuteA      = 10,  // Do not mute A side Dtmf digit once tone detected
 	EnableDTMFMuteB       = 11,  // Mute B side Dtmf digit after tone detected
@@ -174,7 +174,7 @@
     DtmfDigitPnd = 14,    // DTMF Digit # 
     DtmfDigitD   = 15,    // DTMF Digit D 
 
-	FaxCngDigit  = 90,    // Fax Calling Tone (1100 Hz)
+    FaxCngDigit = 90,       // Fax Calling Tone (1100 Hz) 
 
     EndofMFDigit = 100,     // End of MF digit 
     EndofCngDigit = 101     // End of Cng Digit
@@ -188,4 +188,5 @@
 	GPIO_DIR = 2
 } GpakGPIOCotrol_t;
 
+
 #endif // end multiple inclusion




More information about the zaptel-commits mailing list
--- branches/1.2/wcte12xp/GpakErrs.h (original)
+++ branches/1.2/wcte12xp/GpakErrs.h Wed Mar 19 14:58:37 2008
@@ -99,7 +99,8 @@
 
 	Cc_InvalidMuteToneA = 51,        /* invalid MuteToneA set, no detector */
 	Cc_InvalidMuteToneB = 52,         /* invalid MuteToneB set, no detector */
-    Cc_InsuffFaxCngDetResources = 53     /* insufficient tdm block resources avail. */
+    Cc_InsuffFaxCngDetResources = 53,     /* insufficient tdm block resources avail. */
+	Cc_PortDmaNotStarted = 54,     /* SerialPort not ready  */
 
 } GPAK_ChannelConfigStat_t;
 

Modified: branches/1.2/wcte12xp/GpakHpi.h
URL: http://svn.digium.com/view/zaptel/branches/1.2/wcte12xp/GpakHpi.h?view=diff&rev=4028&r1=4027&r2=4028
==============================================================================